@@ -440,7 +440,7 @@ def UpdateWidgetFromPypi():
                         #update
                         widgetReInstall(py_package, package_url, local_path)
                         widgetUpdateNotify(py_package, local_version, remote_version)
-                        store.updateWidgetVersion(it, remote_version)
+                        store.updateWidgetVersion(it, local_path)
                         
                         # 如果daemon之前在运行且应该启动，则重启
                         if daemon_manager_instance and daemon_status.get("running", False):
@@ -501,7 +501,7 @@ def installWidget(name):
         widgetReInstall(name, package_url, local_path)
         widgetInstallNotify(name, remote_version)
         addWidgetToEnv(name, True)
-        store.updateWidgetVersion(widgetid, remote_version)
+        store.updateWidgetInfo(widgetid, local_path)
         print(f"成功安装 {name} {remote_version}")
     else:
         print(f"本地已是最新版本 {remote_version}")
